Trait orchestrator::prelude::ExerciseDef

source ·
pub trait ExerciseDef: Sync + Send + Any {
    // Required methods
    fn description(&self) -> &str;
    fn get_generator_src(&self) -> &str;
    fn list(&self) -> Vec<TestDefinition>;
}
Every exercise must implement this interface. In particular it must implement all the methods and Clone.

In addition to that it must be Send and Sync.

Required Methods

source

fn description(&self) -> &str

return a description

source

fn get_generator_src(&self) -> &str

from which source code was it generate?

source

fn list(&self) -> Vec<TestDefinition>

which test must it generate?

Implementors