Struct orchestrator::prelude::DefaultTest
source · pub struct DefaultTest { /* private fields */ }Expand description
function used to test implementations
- creates an account with a random-name
- logs in that account
- execute an exercise, and expect a full score
Implementations
sourceimpl DefaultTest
impl DefaultTest
sourcepub fn new(t: impl TestInterface + 'static) -> Self
pub fn new(t: impl TestInterface + 'static) -> Self
create a new Test suite, which connects to the orchestrator with the provided TestInterface
sourcepub fn new_default() -> Self
pub fn new_default() -> Self
this create a new DefaultTest with DefaultTestInterface
sourcepub fn set_exercise(&mut self, name: String, code: String)
pub fn set_exercise(&mut self, name: String, code: String)
Use this if you want to test an additional exercise called “name” with the source “code”
pub fn set_additional_function<Fut: Send + Future<Output = Result<(), Box<dyn Error + Send + Sync + 'static>>> + 'static>( &mut self, f: impl Send + Sync + 'static + Fn(Box<dyn TestInterface>) -> Fut, )