Trait orchestrator::prelude::ExerciseDef
source · pub trait ExerciseDef: Sync + Send + Any {
// Required methods
fn description(&self) -> &str;
fn get_generator_src(&self) -> &str;
fn list(&self) -> Vec<TestDefinition>;
}Expand description
Every exercise must implement this interface. In particular it must implement all the methods and Clone.
In addition to that it must be Send and Sync.
Required Methods
sourcefn description(&self) -> &str
fn description(&self) -> &str
return a description
sourcefn get_generator_src(&self) -> &str
fn get_generator_src(&self) -> &str
from which source code was it generate?
sourcefn list(&self) -> Vec<TestDefinition>
fn list(&self) -> Vec<TestDefinition>
which test must it generate?